import { store } from 'https://unpkg.com/@startinblox/core@0.9';
const sibAuth = document.querySelector('sib-auth');

const context = {
  '@vocab': 'http://happy-dev.fr/owl/#',
  rdf: 'http://www.w3.org/1999/02/22-rdf-syntax-ns#',
  rdfs: 'http://www.w3.org/2000/01/rdf-schema#',
  ldp: 'http://www.w3.org/ns/ldp#',
  foaf: 'http://xmlns.com/foaf/0.1/',
  name: 'rdfs:label',
  acl: 'http://www.w3.org/ns/auth/acl#',
  permissions: 'acl:accessControl',
  mode: 'acl:mode',
  geo: "http://www.w3.org/2003/01/geo/wgs84_pos#",
  lat: "geo:lat",
  lng: "geo:long",
  'mentor_profile': 'http://happy-dev.fr/owl/#mentor_profile',
  'entrepreneur_profile': 'http://happy-dev.fr/owl/#entrepreneur_profile',
};

//We create a custom element
class CoopStarterLoginComponent extends HTMLElement {

  // Those function will be call the element is connected to the dom
  async connectedCallback() {
    document.getElementById("mentor_login").onclick = () => this.triggerLogin();
    this.update();
  }

  async triggerLogin() {
    let loader = document.getElementById('main-loader');
    loader.removeAttribute('hidden');
    await sibAuth.login();
  }

  decodeId(id) {
    let slashReplace = '~_';
    let colonReplace = '~@';
    let dotReplace = '~!';
    let tildeReplace = '~~';
    if (!id) return '';
    return id.replace(new RegExp(`\\${colonReplace}`, 'g'), ':')
      .replace(new RegExp(`\\${slashReplace}`, 'g'), '/')
      .replace(new RegExp(`\\${dotReplace}`, 'g'), '.')
      .replace(new RegExp(`\\${tildeReplace}`, 'g'), '~')
      .replace(/^@/, '');
  }

  
  async update() {
    let loader = document.getElementById('main-loader');
    loader.removeAttribute('hidden');
    let user = await sibAuth.getUser();

    //Set a userprefix default status
    var userPrefix = "public"
    
    // Idenfify the space we should go
    if (user) {
      await store.initGraph(user['@id'], context);
      let userFromStore = await store.get(user['@id']);
      
      //If the user is a mentor or an entreprenur, change user prefix
      if(user) {
        let is_mentor = await userFromStore.mentor_profile;
        let is_entrepreneur = await userFromStore.entrepreneur_profile;
        if (is_mentor) {
          userPrefix = "mentor"
        } else if(is_entrepreneur) {
          userPrefix = "entrepreneur"
        }
      }
    }

    //If the url asked pointed to a resource
    if (window.location.href.indexOf('resource-detail') > -1) {
      var newUrl = window.location.href.replace(/\/([a-z]+)-dashboard\/([a-z]+)-resource-detail/, `/${userPrefix}-dashboard/${userPrefix}-resource-detail`)

      //If the url is different after the treatment, we reload with the good url
      if(newUrl !== window.location.href){
        console.log(newUrl);
        var newRoute = new URL(newUrl).pathname.replace(/^\/([a-z]{2})\//, "");
        console.log(newRoute.split(/\/(.*?)\//)[1]);
        window.dispatchEvent(
          new CustomEvent('requestNavigation', { 
            detail: {
              route: newRoute.split(/\/(.*?)\//)[1],
              resource: { "@id": this.decodeId(newRoute.split(/@(.+)/)[1]) }
            }
          })
        );
      } else {
        loader.toggleAttribute('hidden', true);
      }
    } else {
      //User is a mentor
      if (userPrefix === "mentor") {
        window.dispatchEvent(
            new CustomEvent('requestNavigation', { detail: { route: 'mentor-dashboard' } })
          );
      //User is a entrepreneur
      } else if (userPrefix === "entrepreneur") {
        window.dispatchEvent(
          new CustomEvent('requestNavigation', { detail: { route: 'entrepreneur-dashboard' } })
        );
      } else if(user) {
        window.dispatchEvent(
          new CustomEvent('requestNavigation', { detail: { route: 'account-creation' } })
        );
      } else {
        window.dispatchEvent(
          new CustomEvent('requestNavigation', { detail: { route: 'splash' } })
        );
      }
    }
  }
  empty(){}
  populate(){}
}
customElements.define('cs-login', CoopStarterLoginComponent);